@@ -24,10 +24,10 @@ def igra(file_dir, stat=[], save='', save_dir='' ):
                     q1 = xr.DataArray(pd.DataFrame(dfa1[4]),  coords=[ m0,lev], dims=['time','lev'])
                     jj.append(q1)
                 except:
-		    dummy_date = pd.date_range('01-01-1950','01-01-2022')
-		    myArr = np.empty((len(dummy_date),1))
-		    q1_masked = xr.DataArray(myArr, coords=[dummy_date, lev], dims=['time','lev'])
-		    jj.append(q1_masked)
+                    dummy_date = pd.date_range('01-01-1950','01-01-2022')
+                    myArr = np.empty((len(dummy_date),1))
+                    q1_masked = xr.DataArray(myArr, coords=[dummy_date, lev], dims=['time','lev'])
+                    jj.append(q1_masked)
                 pp = []
             c = xr.combine_by_coords(jj)
             jj = []
@@ -54,10 +54,10 @@ def igra(file_dir, stat=[], save='', save_dir='' ):
                         q1 = xr.DataArray(pd.DataFrame(dfa1[4]),  coords=[ m0,lev], dims=['time','lev'])
                         jj.append(q1)
                     except:
-		        dummy_date = pd.date_range('01-01-1950','01-01-2022')
-		        myArr = np.empty((len(dummy_date),1))
-		        q1_masked = xr.DataArray(myArr, coords=[dummy_date, lev], dims=['time','lev'])
-		        jj.append(q1_masked)
+                        dummy_date = pd.date_range('01-01-1950','01-01-2022')
+                        myArr = np.empty((len(dummy_date),1))
+                        q1_masked = xr.DataArray(myArr, coords=[dummy_date, lev], dims=['time','lev'])
+                        jj.append(q1_masked)
                     pp = []
                 c = xr.combine_by_coords(jj)
                 jj = []
@@ -67,4 +67,12 @@ def plot_fig(var):
     plt.figure(figsize=(12,4), dpi=200)
     var.T.plot(cmap='jet', ylim=(1000,100))
     plt.show()
+
+def RH(temp,vapr):
+    temp1, vapr1 = temp/10, vapr/1000
+    es = 6.112*np.exp((17.62*temp1)/(temp1+243.12))
+    return vapr1/(es)*100
+
+def SH(vapr):
+    return 0.622*(vapr/vapr.lev)
         
